"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var stomp_client_common_1 = require("./stomp-client.common");
var StompClient = (function (_super) {
    __extends(StompClient, _super);
    function StompClient(callback) {
        if (callback === void 0) { callback = null; }
        var _this = _super.call(this, callback) || this;
        _this.mStompClient = null;
        _this.topicCallback = new io.reactivex.functions.Consumer({
            accept: function (topicMessage) {
                console.log(topicMessage.getStompCommand() + ' ' + topicMessage.getPayload());
                if (me.delegate) {
                    me.delegate.stompClientDidReceiveMessage(me, undefined, topicMessage.getPayload());
                }
            }
        });
        _this.topicCallbackError = new io.reactivex.functions.Consumer({
            accept: function (throwable) {
                console.log('Error subscribing the topic' + throwable.getMessage());
                if (me.delegate) {
                    me.delegate.serverDidSendError(me, throwable.getMessage(), throwable.getMessage());
                }
            }
        });
        var me = _this;
        _this.connectionEventsCallback = new io.reactivex.functions.Consumer({
            accept: function (lifecycleEvent) {
                console.log("lifecycleEvent: " + lifecycleEvent.getType());
                switch (lifecycleEvent.getType()) {
                    case ua.naiksoftware.stomp.dto.LifecycleEvent.Type.OPENED:
                        console.log('Stomp connection opened');
                        if (me.delegate) {
                            me.delegate.stompClientDidConnect(me);
                        }
                        break;
                    case ua.naiksoftware.stomp.dto.LifecycleEvent.Type.ERROR:
                        console.log('Error: ' + lifecycleEvent.getException());
                        if (me.delegate) {
                            me.delegate.serverDidSendError(me, lifecycleEvent.getException(), lifecycleEvent.getException());
                        }
                        break;
                    case ua.naiksoftware.stomp.dto.LifecycleEvent.Type.CLOSED:
                        console.log('Stomp connection closed');
                        if (me.delegate) {
                            me.delegate.stompClientDidDisconnect(me);
                        }
                        break;
                    default:
                        console.log('Case not found');
                }
            }
        });
        _this.connectionEventsCallbackError = new io.reactivex.functions.Consumer({
            accept: function (throwable) {
                console.log('lifecycleEvent Error' + throwable.getMessage());
                if (me.delegate) {
                    me.delegate.serverDidSendError(me, throwable.getMessage(), throwable.getMessage());
                }
            }
        });
        _this.sendCallback = new io.reactivex.functions.Action({
            run: function () {
                console.log('Message sent');
                if (me.delegate) {
                    me.delegate.serverDidSendReceipt(me, undefined);
                }
            }
        });
        _this.sendCallbackError = new io.reactivex.functions.Consumer({
            accept: function (throwable) {
                console.log('Error sending the message' + throwable.getMessage());
                if (me.delegate) {
                    me.delegate.serverDidSendError(me, throwable.getMessage(), throwable.getMessage());
                }
            }
        });
        return _this;
    }
    StompClient.prototype.openSocketWithURL = function (url) {
        console.log('openSocketWithURL');
        if (this.mStompClient) {
            this.disconnect();
        }
        this.currentUrl = url;
        this.mStompClient = ua.naiksoftware.stomp.Stomp.over(ua.naiksoftware.stomp.Stomp.ConnectionProvider.OKHTTP, url);
        this.mStompClient.lifecycle().subscribe(this.connectionEventsCallback, this.connectionEventsCallbackError);
        this.mStompClient.connect();
    };
    StompClient.prototype.subscribe = function (destination) {
        console.log('subscribe: ' + destination);
        this.mStompClient.topic(destination).subscribe(this.topicCallback, this.topicCallbackError);
    };
    StompClient.prototype.disconnect = function () {
        console.log('disconnect');
        if (this.mStompClient) {
            this.currentUrl = null;
            this.mStompClient.disconnect();
            this.mStompClient = null;
        }
    };
    StompClient.prototype.sendMessage = function (message, toDestination, withHeaders, withReceipt) {
        console.log('sendMessage: ' + toDestination);
        if (this.mStompClient) {
            this.mStompClient.send(toDestination, message).subscribe(this.sendCallback, this.sendCallbackError);
        }
    };
    return StompClient;
}(stomp_client_common_1.StompClientCommon));
exports.StompClient = StompClient;
//# sourceMappingURL=stomp-client.android.js.map